@@ -28,7 +28,8 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
     accessing **self._db** or **self._collection** properties.
 
     ### Configuration parameters ###
-        - collection:                  (optional) Postgres collection name
+        - table:                      (optional) PostgreSQL table name
+        - schema:                     (optional) PostgreSQL schema name
         - connection(s):
             - discovery_key:             (optional) a key to retrieve the connection from :class:`IDiscovery <pip_services3_components.connect.IDiscovery.IDiscovery>`
             - host:                      host name or IP address
@@ -81,7 +82,8 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
     """
 
     __default_config = ConfigParams.from_tuples(
-        "collection", None,
+        "table", None,
+        "schema", None,
         "dependencies.connection", "*:connection:postgres:*:1.0",
 
         # connections.*
@@ -95,15 +97,19 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
         "options.debug", True
     )
 
-    def __init__(self, table_name: str = None):
+    def __init__(self, table_name: str = None, schema_name: str = None):
         """
         Creates a new instance of the persistence component.
 
         :param table_name: (optional) a table name.
+        :param schema_name: (optional) a schema name.
         """
         # The PostgreSQL table object.
         self._table_name = table_name
 
+        # The PostgreSQL schema object.
+        self._schema_name = schema_name
+
         self.__config: ConfigParams = None
         self.__references: IReferences = None
         self.__opened: bool = None
@@ -125,6 +131,7 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
         # The PostgreSQL database name.
         self._database_name: str = None
 
+        # Maximum number of objects in data pages
         self._max_page_size = 100
 
     def configure(self, config: ConfigParams):
@@ -193,8 +200,11 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
         if options.get('unique'):
             builder += " UNIQUE"
 
-        builder += " INDEX IF NOT EXISTS " + self._quote_identifier(name) + " ON " + self._quote_identifier(
-            self._table_name)
+        index_name = self._quote_identifier(name)
+        if self._schema_name is not None:
+            index_name = self._quote_identifier(self._schema_name) + '.' + index_name
+
+        builder += " INDEX IF NOT EXISTS " + index_name + " ON " + self._quoted_table_name()
 
         if options.get('type'):
             builder += " " + options['type']
@@ -283,6 +293,16 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
 
         return '"' + value + '"'
 
+    def _quoted_table_name(self) -> Optional[str]:
+        if self._table_name is None:
+            return None
+
+        builder = self._quote_identifier(self._table_name)
+        if self._schema_name is not None:
+            builder += self._quote_identifier(self._schema_name) + '.' + builder
+
+        return builder
+
     def is_open(self) -> bool:
         """
         Checks if the component is opened.
@@ -317,7 +337,7 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
 
         self._client = self._connection.get_connection()
         # add query method
-        self._client.query = self.__query
+        self._request = self._request
 
         self._database_name = self._connection.get_database_name()
 
@@ -331,7 +351,7 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
             self._logger.debug(correlation_id,
                                "Connected to postgres database %s, collection %s",
                                self._database_name,
-                               self._quote_identifier(self._table_name))
+                               self._table_name)
         except Exception as err:
             raise ConnectionException(correlation_id, "CONNECT_FAILED", "Connection to postgres failed").with_cause(err)
 
@@ -357,7 +377,7 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
             self.__opened = False
             self._client = None
 
-    # def __query(self, query, params=None):
+    # def _request(self, query, params=None):
     #
     #     conn = self._client.getconn()
     #     cursor = conn.cursor()
@@ -374,7 +394,14 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
     #     self._client.putconn(conn)
     #     return response, cursor
 
-    def __query(self, query: str, params: List[str] = None) -> dict:
+    def _request(self, query: str, params: List[str] = None) -> dict:
+        """
+        Performs a request to the database.
+
+        :param query: string with sql query to database
+        :param params: optional list of query parameters
+        :return: result of the query
+        """
         result = {'rowcount': None,
                   'items': [],
                   'statusmessage': None
@@ -417,10 +444,10 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
         if self._table_name is None:
             raise Exception('Table name is not defined')
 
-        query = "DELETE FROM " + self._quote_identifier(self._table_name)
+        query = "DELETE FROM " + self._quoted_table_name()
 
         try:
-            # self._client.query(query) # TODO
+            # self._request(query)
             conn = self._client.getconn()
             cursor = conn.cursor()
             cursor.execute(query)
@@ -441,9 +468,10 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
             return None
 
         # Check if table exist to determine weither to auto create objects
+        # Todo: Add support for schema
         query = "SELECT to_regclass('" + self._table_name + "')"
 
-        result = self._client.query(query)
+        result = self._request(query)
 
         # If table already exists then exit
         if result['items'] and len(result['items']) > 0 and result['items'][0]['to_regclass'] is not None:
@@ -455,7 +483,7 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
         # Run all DML commands
         try:
             for dlm in self.__schema_statements:
-                self._client.query(dlm)
+                self._request(dlm)
         except Exception as err:
             self._logger.error(correlation_id, err, 'Failed to autocreate database object')
 
@@ -534,7 +562,7 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
         :return: a data page or error
         """
         select = select if select and len(select) > 0 else '*'
-        query = "SELECT " + select + " FROM " + self._quote_identifier(self._table_name)
+        query = "SELECT " + select + " FROM " + self._quoted_table_name()
 
         # Adjust max item count based on configuration
         paging = paging or PagingParams()
@@ -554,7 +582,7 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
 
         query += " LIMIT " + str(take)
 
-        result = self._client.query(query)
+        result = self._request(query)
         items = result['items']
 
         if items is not None:
@@ -563,11 +591,11 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
         items = list(map(self._convert_to_public, items))
 
         if paging_enabled:
-            query = 'SELECT COUNT(*) AS count FROM ' + self._quote_identifier(self._table_name)
+            query = 'SELECT COUNT(*) AS count FROM ' + self._quoted_table_name()
             if filter is not None and filter != '':
                 query += " WHERE " + filter
 
-            result = self._client.query(query)
+            result = self._request(query)
 
             count = LongConverter.to_long(result['rows'][0]['count']) if result['rows'] and len(
                 result['rows']) == 1 else 0
@@ -586,12 +614,12 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
         :param filter: (optional) a filter JSON object
         :return: a data page or error
         """
-        query = 'SELECT COUNT(*) AS count FROM ' + self._quote_identifier(self._table_name)
+        query = 'SELECT COUNT(*) AS count FROM ' + self._quoted_table_name()
 
         if filter and filter != '':
             query += " WHERE " + filter
 
-        result = self._client.query(query)
+        result = self._request(query)
 
         count = LongConverter.to_long(result['items'][0]['count']) if result['items'] and len(
             result['items']) == 1 else 0
@@ -616,7 +644,7 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
         """
 
         select = select if len(select) > 0 else '*'
-        query = "SELECT " + select + " FROM " + self._quote_identifier(self._table_name)
+        query = "SELECT " + select + " FROM " + self._quoted_table_name()
 
         if filter and filter != '':
             query += " WHERE " + filter
@@ -624,7 +652,7 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
         if sort:
             query += " ORDER BY " + sort
 
-        items = self._client.query(query)
+        items = self._request(query)
 
         if items is not None:
             self._logger.trace(correlation_id, "Retrieved %d from %s", len(items), self._table_name)
@@ -643,13 +671,13 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
         :param filter: (optional) a filter JSON object
         :return: a random item
         """
-        query = 'SELECT COUNT(*) AS count FROM ' + self._quote_identifier(self._table_name)
+        query = 'SELECT COUNT(*) AS count FROM ' + self._quoted_table_name()
         if filter and filter != '':
             query += " WHERE " + filter
 
-        result = self._client.query(query)
+        result = self._request(query)
 
-        query = "SELECT * FROM " + self._quote_identifier(self._table_name)
+        query = "SELECT * FROM " + self._quoted_table_name()
 
         if filter and filter != '':
             query += " WHERE " + filter
@@ -658,7 +686,7 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
         pos = random.randint(0, count - 1)
         query += f" OFFSET {pos} LIMIT 1"
 
-        result = self._client.query(query)
+        result = self._request(query)
 
         items = result['rows']
         item = items[0] if items is not None and len(items) > 0 else None
@@ -688,10 +716,9 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
         params = self._generate_parameters(row)
         values = self._generate_values(row)
 
-        query = "INSERT INTO " + self._quote_identifier(
-            self._table_name) + " (" + columns + ") VALUES (" + params + ") RETURNING *"
+        query = "INSERT INTO " + self._quoted_table_name() + " (" + columns + ") VALUES (" + params + ") RETURNING *"
 
-        result = self._client.query(query, values)
+        result = self._request(query, values)
         self._logger.trace(correlation_id, "Created in %s with id = %s", self._table_name, row['id'])
 
         new_item = self._convert_to_public(result['items'][0]) if result['items'] and result['items'][0] and len(
@@ -710,11 +737,11 @@ class PostgresPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpen
         :param filter: (optional) a filter JSON object.
         :return: null for success
         """
-        query = "DELETE FROM " + self._quote_identifier(self._table_name)
+        query = "DELETE FROM " + self._quoted_table_name()
         if filter and filter != '':
             query += " WHERE " + filter
 
-        result = self._client.query(query)
+        result = self._request(query)
 
         count = result['rowcount'] if result['rowcount'] else 0
 
